pub struct ConsensusAbciApplication<'a, C> { /* private fields */ }Expand description
AbciApp is an implementation of ABCI Application, as defined by Tenderdash.
AbciApp implements logic that should be triggered when Tenderdash performs various operations, like creating new proposal or finalizing new block.
Implementations