pub enum AbciError {
Show 21 variants
InvalidState(String),
RequestForWrongBlockReceived(String),
VoteExtensionMismatchReceived {
got: Vec<VoteExtension>,
expected: Vec<ExtendVoteExtension>,
},
VoteExtensionsSignatureInvalid,
InvalidVoteExtensionsVerification,
WithdrawalTransactionsDBLoadError(String),
FinalizeBlockReceivedBeforeProcessing(String),
WrongBlockReceived(String),
WrongFinalizeBlockReceived(String),
BadRequestDataSize(String),
BadRequest(String),
BadInitialization(String),
BadCommitSignature(String),
InvalidChainLock(String),
ChainLockedBlockNotKnownByCore(String),
Tenderdash(Error),
TenderdashProto(Error),
BlsErrorFromUserMessage(BlsError),
BlsErrorOfTenderdashThresholdMechanism(BlsError, String),
AbciVersionMismatch {
tenderdash: String,
drive: String,
},
InvalidStateTransition(ConsensusError),
}Expand description
Error returned within ABCI server
Variants
InvalidState(String)
Invalid system state
RequestForWrongBlockReceived(String)
Request does not match currently processed block
VoteExtensionMismatchReceived
Withdrawal votes extensions mismatch
VoteExtensionsSignatureInvalid
Vote extensions signature is invalid
InvalidVoteExtensionsVerification
Invalid votes extensions verification
WithdrawalTransactionsDBLoadError(String)
Cannot load withdrawal transactions
FinalizeBlockReceivedBeforeProcessing(String)
Wrong finalize block received
WrongBlockReceived(String)
Wrong finalize block received
WrongFinalizeBlockReceived(String)
Wrong finalize block received
BadRequestDataSize(String)
Bad request received from Tenderdash that can’t be translated to the correct size This often happens if a Vec<> can not be translated into a [u8;32]
BadRequest(String)
Bad request received from Tenderdash
BadInitialization(String)
Bad initialization from Tenderdash
BadCommitSignature(String)
Bad commit signature from Tenderdash
InvalidChainLock(String)
The chain lock received was invalid
ChainLockedBlockNotKnownByCore(String)
The chain lock received was invalid
Tenderdash(Error)
Error returned by Tenderdash-abci library
TenderdashProto(Error)
Error occurred during protobuf data manipulation
BlsErrorFromUserMessage(BlsError)
Error occurred during signature verification or deserializing a BLS primitive
BlsErrorOfTenderdashThresholdMechanism(BlsError, String)
Error occurred related to threshold signing, either of commit
AbciVersionMismatch
Incompatibility version Error on info handshake between Drive ABCI and Tenderdash
InvalidStateTransition(ConsensusError)
Generic with code should only be used in tests