Loggers

Struct Loggers 

pub struct Loggers(/* private fields */);
Collection of loggers defined using LogBuilder.

This struct holds a collection of loggers created using the LogBuilder. It provides methods for installing, flushing, and rotating logs.

Implementations

Source

impl Loggers

pub fn install(&self)

Installs loggers as a global tracing handler.

Installs loggers prepared in the LogBuilder as a global tracing handler. It must be called exactly once. Panics if a global tracing handler was already defined.

Examples
use drive_abci::logging::{LogBuilder, Loggers};

// Create logger(s) using LogBuilder
let mut logger_builder = LogBuilder::new();
// Configure logger_builder using its methods

// Build Loggers instance
let loggers: Loggers = logger_builder.build();

// Install loggers as a global tracing handler
loggers.install();
Panics

This method panics if the logging subsystem is already initialized.

pub fn get(&self, id: &str) -> Option<&Logger>

Returns a Logger with the specified ID.

pub fn as_subscriber(&self) -> Result<Dispatch, Error>

Build a subscriber containing all layers from these loggers.

pub fn try_install(&self) -> Result<(), Error>

Installs loggers prepared in the LogBuilder as a global tracing handler.

Same as Loggers::install(), but returns error if the logging subsystem is already initialized.

Example

The following code can be used in tests. It ignores errors, as tests might actually call it more than once, and we don’t want to panic in this case.

drive_abci::logging::Loggers::default().try_install().ok();
pub fn tracing_subscriber_layers( &self, ) -> Result<Vec<Box<impl Layer<Registry>>>, Error>

Returns tracing subscriber layers

pub fn flush(&self) -> Result<(), Error>

Flushes all loggers.

In case of multiple errors, returns only the last one.

Errors

Returns an error if there’s an issue flushing any of the loggers.

pub fn rotate(&self) -> Result<(), Error>

Triggers log rotation for log destinations that support this.

In case of multiple errors, returns the error from the last logger.

Errors

Returns an error if there’s an issue rotating any of the logs.