LogConfigs

Type Alias LogConfigs 

pub type LogConfigs = HashMap<String, LogConfig>;
Configuration of log destinations.

Logs can be sent to multiple destinations. Configuration of each of them is prefixed with ABCI_LOG_<key>_, where <key> is some arbitrary alphanumeric name of log configuration.

Key must match pattern [A-Za-z0-9]+.

Note that parsing of LogConfigs is implemented in PlatformConfig::from_env() due to limitations of [envy] crate.

Example

# First logger, logging to stderr on verbosity level 5
ABCI_LOG_STDERR_DESTINATION=stderr
ABCI_LOG_STDERR_LEVEL=trace

# Second logger, logging to stdout on verbosity level 1
ABCI_LOG_STDOUT_DESTINATION=stdout
ABCI_LOG_STDOUT_LEVEL=info

Aliased Type

pub struct LogConfigs { /* private fields */ }