pub fn abci_request_duration(endpoint: &str) -> HistogramTimingExpand description
Returns a [HistogramTiming] instance for measuring ABCI request duration.
Duration measurement starts when this function is called, and stops when returned value goes out of scope.
Arguments
endpoint- A string slice representing the ABCI endpoint name.
Examples
use drive_abci::metrics::abci_request_duration;
let endpoint = "check_tx";
let timing = abci_request_duration(endpoint);
// Your code here
drop(timing); // stop measurement and report the metric