pub trait BlockExecutionApplication {
// Required methods
fn block_execution_context(&self) -> &RwLock<Option<BlockExecutionContext>>;
fn unsigned_withdrawal_txs_by_round(
&self,
) -> &RwLock<UnsignedWithdrawalTxsByRound>;
}Expand description
Application that executes blocks and need to keep context between handlers
Required Methods
Sourcefn block_execution_context(&self) -> &RwLock<Option<BlockExecutionContext>>
fn block_execution_context(&self) -> &RwLock<Option<BlockExecutionContext>>
Returns the current block execution context
Sourcefn unsigned_withdrawal_txs_by_round(
&self,
) -> &RwLock<UnsignedWithdrawalTxsByRound>
fn unsigned_withdrawal_txs_by_round( &self, ) -> &RwLock<UnsignedWithdrawalTxsByRound>
Returns the unsigned withdrawal transactions of every proposal accepted at the current height, by round, which vote extensions are verified against
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".