pub struct PlatformConfig {Show 16 fields
pub network: Network,
pub drive: DriveConfig,
pub core: CoreConfig,
pub abci: AbciConfig,
pub prometheus_bind_address: Option<String>,
pub grpc_bind_address: String,
pub execution: ExecutionConfig,
pub validator_set: ValidatorSetConfig,
pub chain_lock: ChainLockConfig,
pub instant_lock: InstantLockConfig,
pub block_spacing_ms: u64,
pub db_path: PathBuf,
pub rejections_path: Option<PathBuf>,
pub tokio_console_enabled: bool,
pub tokio_console_address: String,
pub tokio_console_retention_secs: u64,
}Expand description
Configuration of Dash Platform.
All fields in this struct can be configured using environment variables.
These variables can also be defined in .env file in the current directory
or its parents. You can also provide path to the .env file as a command-line argument.
Environment variables should be renamed to SCREAMING_SNAKE_CASE.
For example, to define verify_sum_trees, you should set VERIFY_SUM_TREES
environment variable:
export VERIFY_SUM_TREES=true
Fields
network: NetworkThe network type
drive: DriveConfigDrive configuration
core: CoreConfigDash Core config
abci: AbciConfigABCI Application Server config
prometheus_bind_address: Option<String>Address to listen for Prometheus connection.
Optional.
/// Address should be an URL with scheme http://, for example:
http://127.0.0.1:29090
Port number defaults to crate::metrics::DEFAULT_PROMETHEUS_PORT.
grpc_bind_address: StringAddress to listen for gRPC connection.
execution: ExecutionConfigExecution config
validator_set: ValidatorSetConfigThe default quorum type
chain_lock: ChainLockConfigChain lock configuration
instant_lock: InstantLockConfigInstant lock configuration
block_spacing_ms: u64Approximately how often are blocks produced
db_path: PathBufPath to data storage
rejections_path: Option<PathBuf>Path to store rejected / invalid items (like transactions). Used mainly for debugging.
If not set, rejected and invalid items will not be stored.
tokio_console_enabled: boolEnable tokio console (console feature must be enabled)
tokio_console_address: StringTokio console address to connect to
tokio_console_retention_secs: u64Number of seconds to store task information if there is no clients connected
Implementations
Sourceimpl PlatformConfig
The platform config
impl PlatformConfig
The platform config
Sourcepub fn default_for_network(network: Network) -> Self
pub fn default_for_network(network: Network) -> Self
The default depending on the network
Sourcepub fn default_local() -> Self
pub fn default_local() -> Self
The default local config
Sourcepub fn default_devnet() -> Self
pub fn default_devnet() -> Self
The default devnet config
Sourcepub fn default_testnet() -> Self
pub fn default_testnet() -> Self
The default testnet config
Sourcepub fn default_mainnet() -> Self
pub fn default_mainnet() -> Self
The default mainnet config